Learn R Programming

gsdensity (version 0.1.2)

el_nn_search: this function is called by 'compute.nn.edges' to convert nearest neighbor identity matrix to edge list

Description

this function is called by 'compute.nn.edges' to convert nearest neighbor identity matrix to edge list

Usage

el_nn_search(nn2_out)

Value

returns edge list

Arguments

nn2_out

nn2_out