Learn R Programming

gsdensity (version 0.1.2)

run.rwr.list: result in a matrix (number of rows = number of cells; number of columns = number of gene sets) reflecting the probability each cell is labeled during the propagation (relevance to the gene set); same idea as run.rwr but with multiple gene sets

Description

result in a matrix (number of rows = number of cells; number of columns = number of gene sets) reflecting the probability each cell is labeled during the propagation (relevance to the gene set); same idea as run.rwr but with multiple gene sets

Usage

run.rwr.list(el, gene_set_list, cells, restart = 0.75)

Value

activity of pathways in cells

Arguments

el

edge list; output of 'compute.nn.edges'

gene_set_list

a list of gene sets

cells

name of cells; usually the same as 'colnames(object)'

restart

the probability of the propagation to restart

Examples

Run this code
# \donttest{
cells <- colnames(pbmc.mtx)
el <- gsdensity::compute.nn.edges(coembed = ce, nn.use = 300)
cv <- run.rwr.list(el = el, gene_set = gene.set.list[1:3], cells = cells)
# }

Run the code above in your browser using DataLab