run.rwr.list: result in a matrix (number of rows = number of cells; number of columns = number of gene sets)
reflecting the probability each cell is labeled during the
propagation (relevance to the gene set); same idea as run.rwr but with multiple
gene sets
Description
result in a matrix (number of rows = number of cells; number of columns = number of gene sets)
reflecting the probability each cell is labeled during the
propagation (relevance to the gene set); same idea as run.rwr but with multiple
gene sets